@@ -1298,9 +1298,6 @@ adj_value_changed_cb (GtkAdjustment *adj, HexWidget *self)
 
 	self->top_line = gtk_adjustment_get_value (adj);
 
-	hex_widget_update_all_auto_highlights (self);
-	hex_widget_invalidate_all_highlights (self);
-
 	gtk_widget_queue_draw (GTK_WIDGET(self));
 }
 
@@ -2348,6 +2345,9 @@ hex_widget_snapshot (GtkWidget *widget, GtkSnapshot *snapshot)
 	else
 		self->vis_lines = self->default_lines;
 
+	hex_widget_update_all_auto_highlights (self);
+	hex_widget_invalidate_all_highlights (self);
+
 	/* queue child draw functions
 	 */
 
@@ -2951,6 +2951,17 @@ hex_widget_init (HexWidget *self)
 	gtk_widget_add_controller (widget,
 			GTK_EVENT_CONTROLLER(controller));
 
+	/* Event controller - focus */
+
+	controller = gtk_event_controller_focus_new ();
+
+	g_signal_connect_swapped (controller, "enter",
+			G_CALLBACK(gtk_widget_queue_draw), widget);
+	g_signal_connect_swapped (controller, "leave",
+			G_CALLBACK(gtk_widget_queue_draw), widget);
+
+	gtk_widget_add_controller (widget, GTK_EVENT_CONTROLLER(controller));
+
 	/* Connect signal for adjustment */
 
 	g_signal_connect (self->adj, "value-changed",
